pub fn scan_crate_source(root: &Path) -> Result<CrateSourceScanReport>Expand description
Scan a crate source tree and return a static motif report.
pub fn scan_crate_source(root: &Path) -> Result<CrateSourceScanReport>Scan a crate source tree and return a static motif report.