pub struct EpisodeBuilder { /* private fields */ }Expand description
Builder for constructing episodes incrementally as observations arrive.
Implementations
Sourceimpl EpisodeBuilder
impl EpisodeBuilder
Sourcepub fn open(
&mut self,
timestamp_ns: u64,
grammar_state: GrammarState,
reason_code: ReasonCode,
source: ResidualSource,
)
pub fn open( &mut self, timestamp_ns: u64, grammar_state: GrammarState, reason_code: ReasonCode, source: ResidualSource, )
Open a new episode at the given timestamp with the given state.
Sourcepub fn update(&mut self, residual: f64, drift: f64, slew: f64)
pub fn update(&mut self, residual: f64, drift: f64, slew: f64)
Update the current open episode with a new observation.